 /***********************************************************************
 * ping.c
 *
 *  Created on: 28/12/2014
 *      Author: javier
 *
 * Project:	TFC_Library
 * File:	ping.c
 * Description:
 * 			This library contains functions to get de distance either
 *			in centimeters or in inches from the voltage value given by the
 * 			ultrasonic sensor MaxSonar-EZ0.
 *			It uses the ADC driver to read the escaling value and
 *			makes the conversion form milliVolts to inches/centimeters 
 *			
 *
 ***********************************************************************/

#ifndef PING_H_
#define PING_H_


/*****************************************************************************
 * Function name: pingInit
 *
 * Descriptions:Initializes the selected ADC channel and clk to be used
 *
 * parameters:			channel: The ADC channel to initialize
 *
 * Returned value:		void
 *
 *****************************************************************************/
void pingInit(uint8_t channel);

/*****************************************************************************
 * Function name: pingGetDistanceInches
 *
 * Descriptions:Reads the ADC voltage value and performs a conversion
 * 				volts-inches given by the manufacturer of sensor
 * 				LV-MaxSonar-EZ0.
 *
 * 			 	Function: value/ADC_COUNT_MAX)*ULTRASONIC_CONSTANT, where
 *
 * 			 	value: Voltage obtained on ping AN of sensor
 * 			 	ADC_COUNT_MAX: Maximum scaling level on LPC1769, since ADC
 * 			 	has 12 bits	(2^12=4096) from 0 to 4095
 * 			 	ULTRASONIC_CONSTANT: scaling constant given by manufatrurer
 *
 *
 * parameters:			none
 *
 * Returned value:		double: The distance in inches
 *
 *****************************************************************************/
float pingGetDistanceInches();

/*****************************************************************************
 * Function name: pingGetDistanceCm
 *
 * Descriptions:Gets the distance in inches and does the conversion
 * 				from inches to centimeters.
 *
 * parameters:
 *
 * Returned value:		double: The distance in centimeters
 *
 *****************************************************************************/
float pingGetDistanceCm();



#endif /* PING_H_ */
