/***********************************************************************
 *
 *
 *  Created on: 12/10/2014
 *      Author: javier
 *
 * Project:	uprintf
 * File:	uprintf.c
 * Description:
 * 			This library implements the appliances to send and receive
 * 			data through the UART ports in a proper text format.
 *
 ***********************************************************************/

#ifndef UPRINTF_H_
#define UPRINTF_H_


/*****************************************************************************
* Function name: uprintInit
*
* Descriptions:Initializes the UART port that will be used for sending and
* 			   receiving data
*
* parameters:
* 		uartPort: The selected UART port
* 		baudrate: The Baudrate to setup the communication
*
* Returned value: 1 if it manages to initialize the UART port properly
*
*****************************************************************************/
uint32_t uprintfInit(uint8_t uartPort,uint32_t baudrate);



/*****************************************************************************
 * Function name:uprintfClear
 *
 * Descriptions:Cleans up the UART
 *
 * parameters:		uint8_t: Uart port to clear
 *
 * Returned value: void
 *
 *****************************************************************************/
void uprintfClear();



/*****************************************************************************
 * Function name: uprintfScanf
 *
 * Descriptions:The function reads the selected UART Buffer for the milliseconds
 * 			   passed as parameter
 *
 * parameters:
 *
 * 			response: pointer to the text received by UART
 * 			timeout: time wait for more data received
 *
 * Returned value:
 *
 *****************************************************************************/
uint32_t uprintfScanf(char *response, uint32_t timeout);



/*****************************************************************************
 * Function name: uprintfSend();
 *
 * Descriptions:	Sends the through the initialized Uart the valued passed to
 * 					the function in same format as printf
 *
 * parameters:		char* chain: pointer to the values passed to the function
 *
 *
 * Returned value: void
 *
 *****************************************************************************/
void uprintfSend(const char *chain, ...);



/*****************************************************************************
 * Function name: uprintfSendLn();
 *
 * Descriptions:	It provides the same functionality as printfSendUart function
 * 					but also adds a CR+LF code to returning the line
 *
 * parameters:		char* chain: pointer to the values passed to the function
 *
 *
 * Returned value: void
 *
 *****************************************************************************/
void uprintfSendLn(const char *chain, ...);






#endif /* UPRINTF_H_ */
