 /***********************************************************************
 * utils.h
 *
 *  Created on: 11/10/2014
 *      Author: javier
 *
 * Project:	TFC_Library
 * File:	utils.h
 * Description:
 * 			This library implements some utilities to be used by several
			project modules.
 *
 ***********************************************************************/

#ifndef UTILS_H_
#define UTILS_H_

/*Macro to cleans up vectors' memory*/

#define FREEMEM(v,len) memset(v,0x00,len)


/*****************************************************************************
 **Function name: utilsGetTime
 *
 ** Descriptions: Gives the current date and time in format
 ** 				dd/mm/yyyy hh:mm:ss
 **
 ** @parameters void
 **
 ** Returned value: char* that contains the current date
 **
 *****************************************************************************/
char* utilsGetTime();

/*****************************************************************************
 **Function name: utilsActiveDelayMs
 *
 ** Descriptions: Implements an active delay
 **
 ** @parameters uint8_t ms: time to delay ms to delay
 **
 ** Returned value: void
 **
 *****************************************************************************/
void utilsActiveDelay(uint32_t ms);

/*****************************************************************************
 **Function name: utilsPassiveDelayMs
 *
 ** Descriptions: Implements a passive delay
 **
 **
 ** parameters uint8_t ms: time to delay ms to delay
 **
 **
 ** Returned value: void
 **
 *****************************************************************************/
void utilsPassiveDelay(uint32_t ms);


/*****************************************************************************
** Function name:		utilsFreeMem
**
** Descriptions:		Clears the memory used by a variable
**
**
** parameters:			var: the variable to be cleared
**
*
** Returned value:		void
**
**
****************************************************************************/

void utilsFreeMem(char* var);



/*****************************************************************************
** Function name:		utilsCheckValue
**
** Descriptions:		Function that allows to find a pattern into received
** 						buffer to check responses of the device
**
** parameters:			char * buffer: uart received string
** 						char * pattern: substring to looked up into buffer
*
** Returned value:		uint8_t 1 if the pattern is found
** 								0 if not
**
****************************************************************************/
uint32_t utilsCheckValue (char *buffer,char *pattern );


/*****************************************************************************
** Function name:		utilsMakeChain
**
** Descriptions:		Function that prepares in a proper format string
**
** parameters:			char * chain: undetermined number of parameters that
** q					will make up the string
*
** Returned value:		char* Pointer to well formated string
**
****************************************************************************/

char* utilsMakeChain(const char *chain, ...);














#endif /* UTILS_H_ */
