 /***********************************************************************
 * vilmaControl.h
 *
 *  Created on: 27/11/2014
 *      Author: javier
 *
 * Project:	TFC_Library
 * File:	utils.h
 * Description:
 * 			This library implements the most important functionalities
 *			of Vilma's project. Such as get, proccess and execute remote			
 *			commands.
 *
 ***********************************************************************/
#ifndef VILMACONTROL_H_
#define VILMACONTROL_H_


/*Temporal para pruebas*/
//void _vilmaControlSendStatus();

/******************************************************************************************************
 * Function name: vilmaControlRemoteInit
 *
 * Descriptions:Initialize the device wireless module on the Vehicle to be able to connect
 * 				via socket TCP to a remote peer
 *
 * parameters:
 * 			remoteIp: The ip address of the remote peer
 * 			remotePort:The port where remote peer will be listening
 * 			localPort: To setup where vilma will be listening for comands
 * 					port is 2000 by default
 * 			remoteHost: the FQDN of the remote peer in case of performing connection
 * 					through the its hostname in place of its ip address (if this configuration
 * 					is selected, the parameter "remoteIp" won't be used no matter if any value have
 * 					passed to the function)
 *
 *
 * Returned value:
 * 				1 if the the setup was successful
 * 				0 Otherwise
 *
 ******************************************************************************************************/
uint8_t vilmaControlRemoteInit (char* remoteIp,uint16_t remotePort,uint16_t localPort,char* remoteHostname);

/******************************************************************************************************
 * Function name: vilmaControlGetSocketData
 *
 * Descriptions:Takes the command sent by the remote peer via the TCP socket connection
 *
 * parameters:
 * 			command: pointer where stores the complete data taken out from the socket
 *
 * Returned value:
 * 				char: pointer to data received on the socket
 *
 ******************************************************************************************************/
char* controlServerGetSocketData();

/******************************************************************************************************
 * Function name: vilmaControlSendSocketData
 *
 * Descriptions:Send a command to the remote peer through the socket TCP
 *
 * parameters:
 * 			command: command to be sent
 * Returned value:
 * 				void
 *
 ******************************************************************************************************/
void vilmaControlSendSocketData(char* command);

/******************************************************************************************************
 * Function name: vilmaControlGetMinRssi
 *
 * Descriptions:Gets the current configured minimum RSSI value permitted
 *
 * parameters: void
 *
 * Returned value:
 * 				int16_t: Minimum RSSI value
 *
 ******************************************************************************************************/
int16_t vilmaControlGetMinRssi();

/******************************************************************************************************
 * Function name: vilmaCotrolGetCurrentRssi
 *
 * Descriptions:Gets the current RSSI value
 *
 * parameters: void
 *
 * Returned value:
 * 				int16_t: Current RSSI value
 *
 ******************************************************************************************************/
int16_t vilmaCotrolGetCurrentRssi();

/******************************************************************************************************
 * Function name: vilmaControlGetCurrentDistance
 *
 * Descriptions:Gets the current distance upto the nearest object in front of the vehicle
 *
 * parameters: void
 *
 * Returned value:
 * 				int23_t: Current distance in centimeters
 *
 ******************************************************************************************************/
uint32_t vilmaControlGetCurrentDistance();



#endif /* VILMACONTROL_H_ */
