 /***********************************************************************
 * utils.h
 *
 *  Created on: 11/10/2014
 *      Author: javier
 *
 * Project:	TFC_Library
 * File:	utils.h
 * Description:
 * 			This library implements some utilities to be used by several
			project modules.
 *
 ***********************************************************************


/* LPC176X and FreeRTOS Libraries */
#include "FreeRTOS.h"
#include "FreeRTOSConfig.h"
#include "LPC17xx.h"
#include "task.h"
#include "uart.h"
#include <stdio.h>
#include <string.h>
#include "utils.h"
#include "math.h"
#include <stdarg.h>
#include "time.h"



/*****************************************************************************
 **Function name: utilsGetTime
 *
 ** Descriptions: Gives the current date and time in format
 ** 				dd/mm@hh:mm:ss
 **
 ** @parameters void
 **
 ** Returned value: char* that contains the current date
 **
 *****************************************************************************/

char* utilsGetTime(){
	time_t t;
	struct tm *tm;
	static char dateTime[100];
	t=time(NULL);
	tm=localtime(&t);
	strftime(dateTime, 100,"%d/%m@%H:%M:%S", tm);
	return dateTime;

}



/*****************************************************************************
 **Function name: utilsActiveDelayMs
 *
 ** Descriptions: Implements an active delay
 **
 ** @parameters uint8_t ms: time to delay ms to delay
 **
 ** Returned value: void
 **
 *****************************************************************************/
void utilsActiveDelay(uint32_t ms){
int i;
	for( i=0;i<(((uint32_t)7140)*ms);i++);

}

/*****************************************************************************
 **Function name: utilsPassiveDelayMs
 *
 ** Descriptions: Implements a passive delay
 **
 **
 ** @parameters uint8_t ms: time to delay ms to delay
 **
 **
 ** Returned value: void
 **
 *****************************************************************************/
void utilsPassiveDelay(uint32_t ms){

	vTaskDelay(ms/portTICK_RATE_MS);
}


/*****************************************************************************
** Function name:		utilsCheckValue
**
** Descriptions:		Function that allows to find a pattern into received
** 						buffer to check responses of the device
**
** parameters:			char * buffer: uart received string
** 						char * pattern: substring to looked up into buffer
*
** Returned value:		uint8_t 1 if the pattern is found
** 								0 if not
**
****************************************************************************/
uint32_t utilsCheckValue (char *buffer,char *pattern ){

	char* found;
	uint32_t response;
	found=strstr(buffer,pattern);

	if (found){
		response=1;
	}
	else{
		response=0;
	}
	//utilsActiveDelay(250);

	return response;
}

/*****************************************************************************
** Function name:		utilsMakeChain
**
** Descriptions:		Function that prepares in a proper format string
**
** parameters:			char * chain: undetermined number of parameters that
** 				will make up the string
*
** Returned value:		char* Pointer to well formated string
**
****************************************************************************/

char* utilsMakeChain(const char *chain, ...){
	va_list args;
	va_start(args,chain);
	static char buffer[BUFSIZE];
	vsprintf(buffer,chain,args);
	va_end(args);
	return buffer;
}





